"use strict";
/*
 * Copyright 2020 NEM
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const service_1 = require("../service");
const CommandUtils_1 = require("../service/CommandUtils");
class HealthCheck extends command_1.Command {
    async run() {
        const { flags } = this.parse(HealthCheck);
        service_1.BootstrapUtils.showBanner();
        await new service_1.BootstrapService(this.config.root).healthCheck(flags);
    }
}
exports.default = HealthCheck;
HealthCheck.description = `It checks if the services created with docker compose are up and running.

This command checks:
- Whether the docker containers are running.
- Whether the services' exposed ports are listening.
- Whether the rest gateways' /node/health are OK.

The health check process handles 'repeat' and custom 'openPort' services.
    `;
HealthCheck.examples = [`$ symbol-bootstrap healthCheck`];
HealthCheck.flags = {
    help: CommandUtils_1.CommandUtils.helpFlag,
    target: CommandUtils_1.CommandUtils.targetFlag,
};
