"use strict";
/*
 * Copyright 2020 NEM
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const service_1 = require("../service");
const CommandUtils_1 = require("../service/CommandUtils");
const clean_1 = require("./clean");
const compose_1 = require("./compose");
const config_1 = require("./config");
const run_1 = require("./run");
class Start extends command_1.Command {
    async run() {
        const { flags } = this.parse(Start);
        service_1.BootstrapUtils.showBanner();
        flags.password = await CommandUtils_1.CommandUtils.resolvePassword(flags.password, flags.noPassword, CommandUtils_1.CommandUtils.passwordPromptDefaultMessage, true);
        await new service_1.BootstrapService(this.config.root).start(flags);
    }
}
exports.default = Start;
Start.description = 'Single command that aggregates config, compose and run in one line!';
Start.examples = [
    `$ symbol-bootstrap start`,
    `$ symbol-bootstrap start -p bootstrap`,
    `$ symbol-bootstrap start -p testnet -a dual`,
    `$ symbol-bootstrap start -p testnet -a dual --password 1234`,
    `$ echo "$MY_ENV_VAR_PASSWORD" | symbol-bootstrap start -p testnet -a dual`,
];
Start.flags = Object.assign(Object.assign(Object.assign(Object.assign({}, compose_1.default.flags), run_1.default.flags), clean_1.default.flags), config_1.default.flags);
