"use strict";
/*
 * Copyright 2020 NEM
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const logger_1 = require("../logger");
const LoggerFactory_1 = require("../logger/LoggerFactory");
const service_1 = require("../service");
const logger = LoggerFactory_1.default.getLogger(logger_1.LogType.System);
class Clean extends command_1.Command {
    async run() {
        service_1.BootstrapUtils.showBanner();
        const report = await new service_1.VerifyService(this.config.root).createReport();
        logger.info(`OS: ${report.platform}`);
        report.lines.forEach((line) => {
            if (line.recommendation) {
                logger.warn(`${line.header}  - Warning! - ${line.message} - ${line.recommendation}`);
            }
            else {
                logger.info(`${line.header} - OK! - ${line.message}`);
            }
        });
    }
}
exports.default = Clean;
Clean.description = 'It tests the installed software in the current computer reporting if there is any missing dependency, invalid version, or software related issue.';
Clean.examples = [`$ symbol-bootstrap verify`];
Clean.flags = {
    help: service_1.CommandUtils.helpFlag,
};
